@@ -10,14 +10,11 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk._jsii
-import constructs._jsii
-
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/asset-awscli-v1",
-    "2.1.26",
+    "2.2.0",
     __name__[0:-6],
-    "asset-awscli-v1@2.1.26.jsii.tgz",
+    "asset-awscli-v1@2.2.0.jsii.tgz",
 )
 
 __all__ = [
